recurring package
=================

Submodules
----------

recurring.forms module
----------------------

.. automodule:: recurring.forms
   :members:
   :undoc-members:
   :show-inheritance:

recurring.models module
-----------------------

.. automodule:: recurring.models
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recurring
   :members:
   :undoc-members:
   :show-inheritance:
